@@ -99,6 +99,12 @@
  */
 #define DEVICE_PREFIX PLX905X_EEPROM_DEVICE_PREFIX
 
+/*
+ * Bit number to indicate device name registered with devfs for older
+ * kernels if supported.
+ */
+#define PLX905X_STATUS_DEVNAME_REGISTERED	0
+
 /*
  * Redefine pr_debug macro to use "debug" module parameter.
  */
@@ -228,7 +234,7 @@ MODULE_PARM_DESC(bus, "PCI bus number (optional)");
  */
 static unsigned int slot = 0;
 module_param(slot, uint, 0444);
-MODULE_PARM_DESC(bus, "PCI slot number (optional)");
+MODULE_PARM_DESC(slot, "PCI slot number (optional)");
 
 /*
  * PCI vendor ID (optional)
@@ -516,7 +522,7 @@ plx905x_read(struct file *filp, char *buf, size_t count, loff_t *f_pos)
 	if (mutex_lock_interruptible(&dev->mutex)) {
 		return -ERESTARTSYS;
 	}
-	if (!access_ok(buf, count)) {
+	if (!kcompat_access_ok(buf, count)) {
 		retval = -EFAULT;
 		goto out;
 	}
@@ -567,7 +573,7 @@ plx905x_write(struct file *filp, const char *buf, size_t count, loff_t *f_pos)
 	if (mutex_lock_interruptible(&dev->mutex)) {
 		return -ERESTARTSYS;
 	}
-	if (!access_ok(buf, count)) {
+	if (!kcompat_access_ok(buf, count)) {
 		retval = -EFAULT;
 		goto out;
 	}
@@ -850,7 +856,11 @@ plx905x_module_init(void)
 		 */
 		pci_read_config_byte(pcidev, 0x4C, &pvpdcntl);
 		/* Read PCI revision to distinguish PCI9050/9052 */
+#ifdef KCOMPAT_PCI_HAVE_PCI_DEV_REVISION
 		rev = pcidev->revision;
+#else
+		pci_read_config_byte(pcidev, PCI_REVISION_ID, &rev);
+#endif
 		/*
 		 * Check for PCI9030.  PCIBAR0 must be 128 bytes memory
 		 * and its PVDCNTL register must be 0x03
